@@ -109,9 +109,10 @@ def check_file_checksum(df):
     regex_valid_md5sum = re.compile('^[a-f0-9]{32}$')
 
     def _is_str_md5sum(x):
-        match = regex_valid_md5sum.fullmatch(x)
-        if match:
-            return True
+        if pd.notna(x):
+            match = regex_valid_md5sum.fullmatch(x)
+            if match:
+                return True
         else:
             return False
 
@@ -395,8 +396,6 @@ def send_schemas(schema_xmls, url, webin_id, password):
     r = session.post(f"{url}",
                      auth=(webin_id, password),
                      files=sources)
-
-    print(r.text)
     return r
 
 
@@ -614,7 +613,7 @@ def process_args():
                         default=__version__,
                         help='specify the version of the tool this submission is done with')
 
-    parser.add_argument('--no_upload',
+    parser.add_argument('--no_data_upload',
                         default=False,
                         action="store_true",
                         help='Indicate if no upload should be performed and you like to submit a RUN object (e.g. if uploaded was done separately).')
@@ -714,16 +713,12 @@ def main():
             # a dictionary of filename:file_path
             # ? do I have to define the absolute path
             df = schema_targets['run']
-
-            if args.no_upload:
-                file_paths = {}
-                print("No files will be uploaded, remove `--no_upload' argument to perform upload.")
-            else:  # check supplied datafiles only if doing upload
-                file_paths = {os.path.basename(path): os.path.abspath(path)
-                                                   for path in args.data}
-                # check if file names identical between command line and table
-                # if not, system exits
-                check_filenames(file_paths, df)
+               
+            file_paths = {os.path.basename(path): os.path.abspath(path)
+                                                for path in args.data}
+            # check if file names identical between command line and table
+            # if not, system exits
+            check_filenames(file_paths, df)
 
             # generate MD5 sum if not supplied in table
             if not check_file_checksum(df):
@@ -739,8 +734,10 @@ def main():
             schema_targets['run'] = df
 
             # submit data to webin ftp server
-            if not args.no_upload:
+            if not args.no_data_upload:
                 submit_data(file_paths, password, webin_id)
+            else:
+                print("No files will be uploaded, remove `--no_data_upload' argument to perform upload.")
 
         # when adding sample
         # update schema_targets with taxon ids or scientific names
